# hoopR-py
<!-- badges: start -->

![Lifecycle:experimental](https://img.shields.io/badge/lifecycle-experimental-orange.svg?style=for-the-badge&logo=github)
![Contributors](https://img.shields.io/github/contributors/saiemgilani/hoopR-py?style=for-the-badge)
[![Twitter
Follow](https://img.shields.io/twitter/follow/saiemgilani?color=blue&label=%40saiemgilani&logo=twitter&style=for-the-badge)](https://twitter.com/saiemgilani)

<!-- badges: end -->


See [CHANGELOG.md](CHANGELOG.md) for details.

[hoopR-py](https://github.com/saiemgilani/hoopR-py) is an Python package for working with men’s basketball data and companion package to [hoopR](https://github.com/saiemgilani/hoopR)

The package has functions to access live play by play and box score data from ESPN with shot locations when available.

## Installation

hoopR-py can be installed via pip:

```bash
pip install hoopR-py
```

or from the repo (which may at times be more up to date):

```bash
git clone https://github.com/saiemgilani/hoopR-py
cd hoopR-py
pip install -e .
```